import 'package:flutter/material.dart';
import 'package:flx_ui/flx_ui.dart';
import 'package:get/get.dart';

typedef FlxTargetTapCallback = void Function();
typedef FlxTargetLongTapCallback = void Function();
typedef FlxTargetDoubleTapCallback = void Function();

class FlxTarget extends StatelessWidget {
  final Widget? child;

  final FlxTargetTapCallback? onTap;
  final FlxTargetLongTapCallback? onLongTap;
  final FlxTargetDoubleTapCallback? onDoubleTap;

  const FlxTarget({
    Key? key,
    required this.child,
    required this.onTap,
    this.onLongTap,
    this.onDoubleTap,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GetBuilder<FlxTargetController>(
      global: false,
      init: FlxTargetController(),
      builder: (controller) => AnimatedBuilder(
        animation: controller.animationController,
        builder: (context, child) => CustomPaint(
          foregroundPainter: FlxTargetWavePainter(
            splashRadius: controller.radiusAnimation.value,
            splashOpacity: controller.opacityAnimation.value,
            color: Colors.white,
            position: controller.tapPosition ?? Offset(0, 0),
          ),
          child: child,
        ),
        child: GestureDetector(
          onTap: onTap,
          onTapUp: (event) async {
            controller.tapPosition = event.localPosition;

            controller.animationController.duration =
                Duration(milliseconds: 200);
            await controller.animationController.forward(from: 0);

            controller.animationController.duration =
                Duration(milliseconds: 350);
            await controller.animationController.reverse();
          },
          onLongPress: onLongTap,
          onDoubleTap: onDoubleTap,
          child: child,
        ),
      ),
    );
  }
}
