import 'package:flutter/material.dart';
import 'package:flx_ui/components/deep_card/views/deep_card_view.dart';
import 'package:flx_ui/components/text_field/controllers/text_field_controller.dart';
import 'package:flx_ui/flx_ui.dart';
import 'package:get/get_state_manager/src/simple/get_state.dart';

class FlxTextField extends StatelessWidget {
  final double? width;

  final String? placeholder;

  final bool? isConceal;

  final TextEditingController? controller;

  const FlxTextField({
    Key? key,
    this.width,
    this.placeholder,
    this.isConceal,
    this.controller,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GetBuilder<FlxTextFieldController>(
      init: FlxTextFieldController(controller ?? TextEditingController()),
      global: false,
      builder: (FlxTextFieldController controller) => GestureDetector(
        onTap: () => controller.onTap(),
        child: SizedBox(
          width: width,
          height: 42,
          child: FlxFlatCard(
            child: AnimatedContainer(
              duration: Duration(milliseconds: 350),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(12),
                border: Border.all(
                  width: controller.isFocus ? 2 : 0,
                  color: controller.isFocus
                      ? FlxColorTheme.accent(context)
                      : Colors.transparent,
                ),
              ),
              child: AnimatedPadding(
                duration: Duration(milliseconds: 350),
                padding: EdgeInsets.symmetric(
                  horizontal: controller.isFocus ? 14.0 : 16.0,
                ),
                child: Center(
                  child: TextField(
                    controller: controller.textEditingController,
                    focusNode: controller.focusNode,
                    scrollPhysics: const BouncingScrollPhysics(),
                    obscureText: isConceal ?? false,
                    decoration: InputDecoration.collapsed(
                      hintText: placeholder ?? '',
                    ),
                    style: FlxTextTheme.field(context),
                  ),
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
